@@ -30,9 +30,41 @@
 
 #define SCRIPT_ENVVAR "TOTEM_PL_PARSER_VIDEOSITE_SCRIPT"
 
-/* The helper script will be either the one shipped in totem-pl-parser,
- * when running tests, or the first non-hidden file in the totem-pl-parser
- * libexec directory, when sorted by lexicographic ordering (through strcmp) */
+/* totem-pl-parser can "parse" pages from certain websites into a single
+ * video playback URL. This is particularly useful for websites which
+ * show a unique video on a web page, and use one-time URLs to prevent direct
+ * linking.
+ *
+ * This feature is implemented in a helper binary, either the one shipped
+ * in totem-pl-parser (which uses libquvi), or the first non-hidden file in
+ * the totem-pl-parser libexec directory, when sorted by lexicographic
+ * ordering (through strcmp).
+ *
+ * The API to implement is straight-forward. For each URL that needs to
+ * be checked, the script will be called with the command-line arguments
+ * "--check --url" followed by the URL. The script should return the
+ * string "TRUE" if the script knows how to handle video pages from
+ * this site. This call should not making any network calls, and should
+ * be fast.
+ *
+ * If the video site is handled by the script, then the script can be
+ * called with "--url" followed by the URL. The script can return the
+ * strings "TOTEM_PL_PARSER_RESULT_ERROR" or
+ * "TOTEM_PL_PARSER_RESULT_UNHANDLED" to indicate an error (see the
+ * meaning of those values in the totem-pl-parser API documentation), or
+ * a list of "<key>=<value>" pairs separated by newlines characters (\n)
+ * The keys are "metadata fields" in the API documentation, such as:
+ * url=https://www.videosite.com/unique-link-to.mp4
+ * title=Unique Link to MP4
+ * author=Well-known creator
+ *
+ * Integrators should make sure that totem-pl-parser is shipped with at
+ * least one video site parser, either the quvi one offered by
+ * totem-pl-parser itself, or, in a separate package, a third-party parser
+ * that implements a compatible API as explained above. Do *NOT* ship
+ * third-party parsers in the same package as totem itself.
+ */
+
 static char *
 find_helper_script (void)
 {
@@ -81,12 +113,13 @@ totem_pl_parser_is_videosite (const char *uri, gboolean debug)
 	};
 	char *out;
 	char *script;
+	gboolean ret = FALSE;
 
 	script = find_helper_script ();
 	if (script == NULL) {
 		if (debug)
 			g_print ("Did not find a script to check whether '%s' is a videosite\n", uri);
-		return FALSE;
+		return ret;
 	}
 
 	args[0] = script;
@@ -101,13 +134,16 @@ totem_pl_parser_is_videosite (const char *uri, gboolean debug)
 		      NULL,
 		      NULL,
 		      NULL);
+
+	ret = g_strcmp0 (out, "TRUE") == 0;
 	if (debug)
 		g_print ("Checking videosite with script '%s' for URI '%s' returned '%s' (%s)\n",
-			 script, uri, out, g_strcmp0 (out, "TRUE") == 0 ? "true" : "false");
+			 script, uri, out, ret ? "true" : "false");
 
 	g_free (script);
+	g_free (out);
 
-	return (g_strcmp0 (out, "TRUE") == 0);
+	return ret;
 }
 
 #ifndef TOTEM_PL_PARSER_MINI
